@@ -1,6 +1,6 @@
 use proc_macro2::TokenStream;
 
-use ::syn::{self, Data, Ident, Variant, Fields};
+use syn::{self, Data, Fields, Ident, Variant};
 
 use super::Context;
 
@@ -13,7 +13,9 @@ pub fn transcoder_decorator(ast: &syn::DeriveInput) -> TokenStream {
     };
 
     let num_lifetimes = ast.generics.lifetimes().count();
-    if num_lifetimes > 1 { panic!("Enum can only have one lifetime argument"); }
+    if num_lifetimes > 1 {
+        panic!("Enum can only have one lifetime argument");
+    }
     let has_lifetime = num_lifetimes == 1;
 
     for variant in variants {
@@ -22,32 +24,32 @@ pub fn transcoder_decorator(ast: &syn::DeriveInput) -> TokenStream {
                 panic!("NifUntaggedEnum can only be used with enums that contain all NewType variants.");
             }
         } else {
-            panic!("NifUntaggedEnum can only be used with enums that contain all NewType variants.");
+            panic!(
+                "NifUntaggedEnum can only be used with enums that contain all NewType variants."
+            );
         }
     }
 
     let variants: Vec<&Variant> = variants.iter().collect();
 
-    let decoder =
-        if ctx.decode() {
-            gen_decoder(&ast.ident, &variants, has_lifetime)
-        } else {
-            quote! {}
-        };
+    let decoder = if ctx.decode() {
+        gen_decoder(&ast.ident, &variants, has_lifetime)
+    } else {
+        quote! {}
+    };
 
-    let encoder =
-        if ctx.encode() {
-            gen_encoder(&ast.ident, &variants, has_lifetime)
-        } else {
-            quote! {}
-        };
+    let encoder = if ctx.encode() {
+        gen_encoder(&ast.ident, &variants, has_lifetime)
+    } else {
+        quote! {}
+    };
 
-    let gen = quote!{
+    let gen = quote! {
         #decoder
         #encoder
     };
 
-    gen.into()
+    gen
 }
 
 pub fn gen_decoder(enum_name: &Ident, variants: &[&Variant], has_lifetime: bool) -> TokenStream {
@@ -57,16 +59,19 @@ pub fn gen_decoder(enum_name: &Ident, variants: &[&Variant], has_lifetime: bool)
         quote! { #enum_name }
     };
 
-    let variant_defs: Vec<_> = variants.iter().map(|variant| {
-        let variant_name = &variant.ident;
-        let field_type   = &variant.fields.iter().next().unwrap().ty;
+    let variant_defs: Vec<_> = variants
+        .iter()
+        .map(|variant| {
+            let variant_name = &variant.ident;
+            let field_type = &variant.fields.iter().next().unwrap().ty;
 
-        quote! {
-            if let Ok(inner) = #field_type::decode(term) {
-                return Ok( #enum_name :: #variant_name ( inner ) )
+            quote! {
+                if let Ok(inner) = #field_type::decode(term) {
+                    return Ok( #enum_name :: #variant_name ( inner ) )
+                }
             }
-        }
-    }).collect();
+        })
+        .collect();
 
     let gen = quote! {
         impl<'a> ::rustler::Decoder<'a> for #enum_type {
@@ -78,7 +83,7 @@ pub fn gen_decoder(enum_name: &Ident, variants: &[&Variant], has_lifetime: bool)
         }
     };
 
-    gen.into()
+    gen
 }
 
 pub fn gen_encoder(enum_name: &Ident, variants: &[&Variant], has_lifetime: bool) -> TokenStream {
@@ -88,13 +93,16 @@ pub fn gen_encoder(enum_name: &Ident, variants: &[&Variant], has_lifetime: bool)
         quote! { #enum_name }
     };
 
-    let variant_defs: Vec<_> = variants.iter().map(|variant| {
-        let variant_name = &variant.ident;
+    let variant_defs: Vec<_> = variants
+        .iter()
+        .map(|variant| {
+            let variant_name = &variant.ident;
 
-        quote! {
-            #enum_name :: #variant_name ( ref inner ) => inner.encode(env),
-        }
-    }).collect();
+            quote! {
+                #enum_name :: #variant_name ( ref inner ) => inner.encode(env),
+            }
+        })
+        .collect();
 
     let gen = quote! {
         impl<'b> ::rustler::Encoder for #enum_type {
@@ -106,5 +114,5 @@ pub fn gen_encoder(enum_name: &Ident, variants: &[&Variant], has_lifetime: bool)
         }
     };
 
-    gen.into()
+    gen
 }
